# OpenTelemetry Examples

## Installation

### Build the environment

For macOS and Linux:

```bash
$ git clone https://github.com/apiflask/apiflask
$ cd apiflask/examples/otel
$ python3 -m venv venv
$ source venv/bin/activate
$ pip3 install -r requirements.txt
```

For Windows:

```text
> git clone https://github.com/apiflask/apiflask
> cd apiflask\examples\otel
> python -m venv venv
> venv\Scripts\activate
> pip install -r requirements.txt
```

### Run, Flask, Run!

After change into the desired folder, use `flask run` command to run
the example application:

```bash
$ flask run
  * Running on http://127.0.0.1:5000/ (Press CTRL+C to quit)
```

## Try it out

When the application is running, now you can visit <http://localhost:5000/>.
